==> hubzero-cms-2.0.0_2.0.0.0.orig.tar.gz: hubzero-cms-2.0.0-2.0.0.0/cms/core/modules/mod_mytickets/helper.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2015 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

namespace Modules\MyTickets;

use Hubzero\Module\Module;
use Hubzero\User\Profile;
use User;

/**
 * Module class for displaying a user's support tickets
 */
class Helper extends Module
{
	/**
	 * Display module content
	 *
	 * @return  void
	 */
	public function display()
	{
		$database = \App::get('db');

		$this->moduleclass = $this->params->get('moduleclass');
		$limit = intval($this->params->get('limit', 10));

		// Find the user's most recent support tickets
		$database->setQuery(
			"(
				SELECT id, summary, category, open, status, severity, owner, created, login, name,
					(SELECT COUNT(*) FROM #__support_comments as sc WHERE sc.ticket=st.id AND sc.access=0) as comments
				FROM #__support_tickets as st
				WHERE st.login='" . User::get('username') . "' AND st.open=1 AND type=0
				ORDER BY created DESC
				LIMIT $limit
			)
			UNION
			(
				SELECT id, summary, category, open, status, severity, owner, created, login, name,
					(SELECT COUNT(*) FROM #__support_comments as sc WHERE sc.ticket=st.id AND sc.access=0) as comments
				FROM #__support_tickets as st
				WHERE st.owner='" . User::get('id') . "' AND st.open=1 AND type=0
				ORDER BY created DESC
				LIMIT $limit
			)"
		);
		$this->rows = $database->loadObjectList();
		if ($database->getErrorNum())
		{
			$this->setError($database->stderr());
			$this->rows = array();
		}

		$rows1 = array();
		$rows2 = array();

		if ($this->rows)
		{
			foreach ($this->rows as $row)
			{
				if ($row->owner == User::get('id'))
				{
					$rows2[] = $row;
				}
				else
				{
					$rows1[] = $row;
				}
			}
		}

		$this->rows1 = $rows1;
		$this->rows2 = $rows2;

		$profile = Profile::getInstance(User::get('id'));
		$xgroups = $profile->getGroups('members');

		$groups = '';
		if ($xgroups)
		{
			$g = array();
			foreach ($xgroups as $xgroup)
			{
				$g[] = $xgroup->cn;
			}
			$groups = implode("','", $g);
		}

		$this->rows3 = null;
		if ($groups)
		{
			// Find support tickets on the user's contributions
			$database->setQuery(
				"SELECT id, summary, category, open, status, severity, owner, created, login, name,
					(SELECT COUNT(*) FROM `#__support_comments` as sc WHERE sc.ticket=st.id AND sc.access=0) as comments
				FROM `#__support_tickets` as st
				WHERE st.open=1 AND type=0 AND st.group IN ('$groups')
				ORDER BY created DESC
				LIMIT $limit"
			);
			$this->rows3 = $database->loadObjectList();
			if ($database->getErrorNum())
			{
				$this->setError($database->stderr());
				$this->rows3 = null;
			}
		}

		require $this->getLayoutPath();
	}
}

==> hubzero-cms-2.0.0_2.0.0.1.orig.tar.gz: hubzero-cms-2.0.0-2.0.0.1/cms/core/modules/mod_mytickets/helper.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 HUBzero Foundation, LLC.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
 * @license   http://opensource.org/licenses/MIT MIT
 */

namespace Modules\MyTickets;

use Hubzero\Module\Module;
use Hubzero\User\Profile;
use User;

/**
 * Module class for displaying a user's support tickets
 */
class Helper extends Module
{
	/**
	 * Display module content
	 *
	 * @return  void
	 */
	public function display()
	{
		$database = \App::get('db');

		$this->moduleclass = $this->params->get('moduleclass');
		$limit = intval($this->params->get('limit', 10));

		// Find the user's most recent support tickets
		$database->setQuery(
			"(
				SELECT id, summary, category, open, status, severity, owner, created, login, name,
					(SELECT COUNT(*) FROM #__support_comments as sc WHERE sc.ticket=st.id AND sc.access=0) as comments
				FROM #__support_tickets as st
				WHERE st.login='" . User::get('username') . "' AND st.open=1 AND type=0
				ORDER BY created DESC
				LIMIT $limit
			)
			UNION
			(
				SELECT id, summary, category, open, status, severity, owner, created, login, name,
					(SELECT COUNT(*) FROM #__support_comments as sc WHERE sc.ticket=st.id AND sc.access=0) as comments
				FROM #__support_tickets as st
				WHERE st.owner='" . User::get('id') . "' AND st.open=1 AND type=0
				ORDER BY created DESC
				LIMIT $limit
			)"
		);
		$this->rows = $database->loadObjectList();
		if ($database->getErrorNum())
		{
			$this->setError($database->stderr());
			$this->rows = array();
		}

		$rows1 = array();
		$rows2 = array();

		if ($this->rows)
		{
			foreach ($this->rows as $row)
			{
				if ($row->owner == User::get('id'))
				{
					$rows2[] = $row;
				}
				else
				{
					$rows1[] = $row;
				}
			}
		}

		$this->rows1 = $rows1;
		$this->rows2 = $rows2;

		$profile = Profile::getInstance(User::get('id'));
		$xgroups = $profile->getGroups('members');

		$groups = '';
		if ($xgroups)
		{
			$g = array();
			foreach ($xgroups as $xgroup)
			{
				$g[] = $xgroup->cn;
			}
			$groups = implode("','", $g);
		}

		$this->rows3 = null;
		if ($groups)
		{
			// Find support tickets on the user's contributions
			$database->setQuery(
				"SELECT id, summary, category, open, status, severity, owner, created, login, name,
					(SELECT COUNT(*) FROM `#__support_comments` as sc WHERE sc.ticket=st.id AND sc.access=0) as comments
				FROM `#__support_tickets` as st
				WHERE st.open=1 AND type=0 AND st.group IN ('$groups')
				ORDER BY created DESC
				LIMIT $limit"
			);
			$this->rows3 = $database->loadObjectList();
			if ($database->getErrorNum())
			{
				$this->setError($database->stderr());
				$this->rows3 = null;
			}
		}

		require $this->getLayoutPath();
	}
}
